@@ -1,7 +1,7 @@
 # plot method for all smacof objects
 
 plot.smacof <- function(x, plot.type = "confplot", plot.dim = c(1,2), sphere = TRUE, 
-                        main, xlab, ylab, ...)
+                        main, xlab, ylab, xlim, ylim, ...)
 
 # x ... object of class smacof
 # plot.type ... types available: "confplot", "Shepard", "resplot"
@@ -30,7 +30,12 @@ plot.smacof <- function(x, plot.type = "confplot", plot.dim = c(1,2), sphere = T
     if (missing(main)) main <- paste("Configuration Plot") else main <- main
     if (missing(xlab)) xlab <- paste("Configurations D", x1,sep = "") else xlab <- xlab
     if (missing(ylab)) ylab <- paste("Configurations D", y1,sep = "") else ylab <- ylab
-    plot(x$conf[,x1], x$conf[,y1], main = main, type = "n", xlab = xlab, ylab = ylab, ...)
+
+    fullconf <- rbind(x$conf[,x1],x$conf[,y1])
+    if (missing(xlim)) xlim <- range(fullconf)
+    if (missing(ylim)) ylim <- range(fullconf)
+    
+    plot(x$conf[,x1], x$conf[,y1], main = main, type = "n", xlab = xlab, ylab = ylab, xlim = xlim, ylim = ylim, ...)
     if ((any(class(x) == "smacofSP")) && (sphere)) {
       if (x$model == "Spherical SMACOF (dual)") {                     #dual smacof centered around first configuration row
         radius <- sqrt((abs(x$conf[2,1])+abs(x$conf[1,1]))^2 + (abs(x$conf[2,2])+abs(x$conf[1,2]))^2)    #sphere radius dual
@@ -44,31 +49,46 @@ plot.smacof <- function(x, plot.type = "confplot", plot.dim = c(1,2), sphere = T
   }
 
   #---------------- Shepard diagram ------------------
-  #FIXME diagram for spherical
+
   if (plot.type == "Shepard") {
     if (missing(main)) main <- paste("Shepard Diagram") else main <- main
-    if (missing(xlab)) xlab <- "Observed Distances" else xlab <- xlab
+    if (missing(xlab)) xlab <- "Dissimilarities" else xlab <- xlab
     if (missing(ylab)) ylab <- "Configuration Distances" else ylab <- ylab
-    isofit <- isoreg(as.vector(x$obsdiss), as.vector(x$confdiss))  #isotonic regression
+
+    ocdiss <- c(as.vector(x$obsdiss), as.vector(x$confdiss))
+    if (missing(xlim)) xlim <- range(ocdiss)
+    if (missing(ylim)) ylim <- range(ocdiss)
+
     plot(as.vector(x$obsdiss), as.vector(x$confdiss), main = main, type = "p", pch = 1,
-         xlab = xlab, ylab = ylab, col = "lightgray", ...)
-    points(sort(isofit$x), isofit$yf, type = "b", pch = 16)
+         xlab = xlab, ylab = ylab, col = "lightgray", xlim = xlim, ylim = ylim, ...)
+
+    if (!x$metric) {
+      isofit <- isoreg(as.vector(x$obsdiss), as.vector(x$confdiss))  #isotonic regression
+      points(sort(isofit$x), isofit$yf, type = "b", pch = 16)
+    } else {
+      abline(0,1, lty = 2)
+    }
   }
 
   #--------------- Residual plot --------------------
-  #FIXME smacof sphere
+ 
   if (plot.type == "resplot") {
     if (missing(main)) main <- paste("Residual plot") else main <- main
     if (missing(xlab)) xlab <- "Configuration Distances" else xlab <- xlab
     if (missing(ylab)) ylab <- "Residuals" else ylab <- ylab
     resmat <- residuals(x)
+
+    fullres <- c(as.vector(x$confdiss), as.vector(resmat[lower.tri(resmat)])) 
+    if (missing(xlim)) xlim <- range(fullres)
+    if (missing(ylim)) ylim <- range(fullres)
+    
     plot(as.vector(x$confdiss), as.vector(resmat[lower.tri(resmat)]), main = main, type = "p",
-         xlab = xlab, ylab = ylab, ...)
+         xlab = xlab, ylab = ylab, xlim = xlim, ylim = ylim, ...)
     abline(h = 0, col = "lightgray", lty = 2)  
   }
 
   #----------------------- Stress decomposition -----------------
-  #FIXME smacofSphere
+ 
   if (plot.type == "stressplot") {
     if (missing(main)) main <- paste("Stress Decomposition Chart") else main <- main
     if (missing(xlab)) xlab <- "Objects" else xlab <- xlab
@@ -78,8 +98,12 @@ plot.smacof <- function(x, plot.type = "confplot", plot.dim = c(1,2), sphere = T
     decomp.stress <- stress.r/(sum(stress.r))*100
     sdecomp.stress <- sort(decomp.stress, decreasing = TRUE)
     xaxlab <- names(sdecomp.stress)
+
+    if (missing(xlim)) xlim1 <- c(1,length(decomp.stress)) else xlim1 <- xlim
+    if (missing(ylim)) ylim1 <- range(sdecomp.stress) else ylim1 <- ylim
+    
     plot(1:length(decomp.stress), sdecomp.stress, xaxt = "n", type = "p",
-         xlab = xlab, ylab = ylab, main = main, ...)
+         xlab = xlab, ylab = ylab, main = main, xlim = xlim1, ylim = ylim1, ...)
     text(1:length(decomp.stress), sdecomp.stress, labels = xaxlab, pos = 3, cex = 0.8)
     for (i in 1:length(sdecomp.stress)) lines(c(i,i), c(sdecomp.stress[i],0), col = "lightgray", lty = 2)
                                   
