@@ -1,6 +1,8 @@
 `print.smacofID` <-
 function(x,...)
 {
+  cat("\nCall: ")
+  print(x$call)
   cat("\n")
   cat("Model:",x$model,"\n")
   cat("Number of objects:",x$nobj,"\n")
