@@ -88,7 +88,7 @@ function(delta, ndim = 2, weightmat = NULL, init = NULL,
 
 #return configurations, configuration distances, normalized observed distances 
 result <- list(obsdiss = dhat, confdiss = e, conf = y, stress.m = ssma, stress.nm = snon,
-               ndim = p, model = "Symmetric SMACOF", niter = itel, nobj = n) 
+               ndim = p, model = "Symmetric SMACOF", niter = itel, nobj = n, metric = metric, call = match.call()) 
 class(result) <- c("smacofB","smacof")
 result 
 }
